@@ -57,7 +57,7 @@ class _InnerClass:
         )
 
 
-    def ping(self, text="ping :heart:", params={}, **kwargs):
+    def ping(self, text="ping!", params={}, **kwargs):
         return self._post(text = text, info = {**params, **kwargs})
 
 
